## Earth Engine Helper v0.1.3

[![DOI](https://zenodo.org/badge/252678920.svg)](https://zenodo.org/badge/latestdoi/252678920)

Helper library for `Google Earth Engine` python API scripts

Install using 

`pip install eehelper`
